package com.css.simulation.resource.scheduler.feign;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.param.KafkaParameter;
import api.common.pojo.param.MinioParameter;
import com.css.simulation.resource.scheduler.configuration.feign.OpenFeignConfiguration;
import com.css.simulation.resource.scheduler.feign.fallback.DemoServiceFallback;
import feign.Response;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.multipart.MultipartFile;

@Component
@FeignClient(
        value = "simulation-resource-common",
        fallback = DemoServiceFallback.class,
        configuration = OpenFeignConfiguration.class
)
public interface DemoService {

    @PostMapping(value = "/simulation/resource/common/minio/upload", consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    ResponseBodyVO<String> upload(@RequestPart("file") MultipartFile file,
                                  @RequestParam("objectName") String objectName);

    @PostMapping("/simulation/resource/common/minio/download")
    Response download(@RequestBody @Validated MinioParameter minioParameter);


    @PostMapping(value = "/simulation/resource/common/kafka/send", consumes = MediaType.APPLICATION_JSON_VALUE)
    ResponseBodyVO<String> send(@RequestBody @Validated KafkaParameter kafkaParameter);


}
